import { game } from "./game";
import { users } from "./Account/users";
import { loadItems } from "./Items/items";
import { players } from "./Player/players";
import { registerItemCallbacks } from "./Items/itemSocket";
import { registerLobbyCallbacks } from "./Lobby/lobbySocket";
import { registerAccountCallbacks } from "./Account/accountSocket";
import { registerLevelCallbacks } from "./Level/levelSocket";
import { physicsObject } from "./Classes/physicsObject";
import { enemyData } from "./Classes/enemyData";

const express = require("express");
const app = express();
const port = 3000;
const server = require('http').Server(app);

server.listen(port, () => {
  console.log(`Server listening at port ${port}`);
});

const io = require("socket.io")(server, {
	cors: {
        origin: '*',
        methods: ["GET", "POST"]
    }
});

users.loadUsers();
players.loadPlayers();
loadItems()

io.on('connection', (socket) => {
	console.log("Got connection!");
	socket.emit("connectSuccess", "");

    registerAccountCallbacks(socket);
    registerLobbyCallbacks(socket);
    registerItemCallbacks(socket);
    registerLevelCallbacks(socket);
    
    socket.io = game.socketIO = io;

    socket.on("disconnect", () => {
        socket.disconnect()
        if(socket.hasOwnProperty("user")){
            game.lobbyState.removeUser(socket.user.id)
            delete socket.user
        }
        console.log(socket.id + " disconnected");
    });

    socket.on('error',function(er){
        console.log(er);
    });
});

//Send player updates to everyone
setInterval(async () => {
    let userCount = game.lobbyState.players.length
    if(userCount > 0){
        game.lobbyState.rooms.forEach(room=>{
            let roomData = room.copyLight()

            io.in(room.id).emit('lobby/update', JSON.stringify(roomData))
        })
        game.playersDB.forEach(p=>{
            p.damageInfo = []
        })
    }
}, 1000/30)

setInterval(() => {
    let lobbyState = game.lobbyState
    console.log("Players:")
    for(let i = 0; i < lobbyState.players.length; i++){
        console.log(lobbyState.players[i].id + " " + lobbyState.players[i].room)
    }
    console.log("Rooms:")
    for(let i = 0; i < lobbyState.rooms.length; i++){
        console.log(lobbyState.rooms[i].id + " " + lobbyState.rooms[i].hostId)
    }
    console.log("Dungeon:")
    for(let i = 0; i < lobbyState.dungeons.length; i++){
        console.log(lobbyState.dungeons[i].entranceId + " " + lobbyState.dungeons[i].playerCount)
    }
}, 60 * 1000)

process.on('SIGINT', function () {
    console.log('Ctrl-C...');
    process.exit(2);
});
process.on('exit', function () {
    users.saveUsers();
    players.savePlayers();
    console.log("exitted");
});